@@ -91,7 +91,7 @@ class Products extends CGExtensions
 
   function GetDependencies()
   {
-	return array('CGExtensions'=>'1.23',
+	return array('CGExtensions'=>'1.24',
 				 'CGSimpleSmarty'=>'1.4.4');
   }
 
@@ -117,12 +117,12 @@ class Products extends CGExtensions
 
   function GetVersion()
   {
-	return '2.10.5';
+	return '2.11';
   }
 
   function MinimumCMSVersion()
   {
-	return '1.9.1';
+	return '1.9.2';
   }
 
   function GetAdminDescription()
@@ -189,6 +189,10 @@ EOT;
 	$this->SetParameterType('sorttype',CLEAN_STRING);
 // 	$this->CreateParameter('selectcategory',0,$this->Lang('param_selectcategory'));
 // 	$this->SetParameterType('selectcategory',CLEAN_INT);
+	
+	$this->CreateParameter('excludecat','',$this->Lang('param_excludecat'));
+	$this->SetParameterType('excludecat',CLEAN_STRING);
+
 	$this->CreateParameter('category','',$this->Lang('param_category'));
 	$this->SetParameterType('category',CLEAN_STRING);
 	$this->SetParameterType('categoryname',CLEAN_STRING);
