@@ -168,8 +168,6 @@ if( count($where) )
 $qparms = array_merge($jparms,$qparms);
 $query .= " GROUP BY A.id ORDER BY $sortby $sortorder";
 $categories = $db->GetArray($query,$qparms);
-debug_display($db->sql);
-debug_display($db->ErrorMsg());
 if( !$categories )
   {
     return;
