@@ -223,6 +223,13 @@ if( !(is_array($productlist) && count($productlist) > 0) )
 	$categoryid = $params['categoryid'];
       }
 
+    $excludecat = '';
+    if (isset($params['excludecat']) )
+      {
+	$excludecat = trim($params['excludecat']);
+	$excludecat = cms_html_entity_decode($excludecat);
+      }
+
     $hierarchy = '';
     if( isset( $params['hierarchy'] ) )
       {
@@ -282,6 +289,22 @@ if( !(is_array($productlist) && count($productlist) > 0) )
 	$where[] = 'cs.name IN ('.$txt.')';
       }
 
+    if( isset($excludecat) && $excludecat != '' )
+      {
+	$arr1 = explode(',',$excludecat);
+	$arr2 = array();
+	foreach( $arr1 as $xx )
+	  {
+	    $arr2[] = "'".$xx."'";
+	  }
+	$txt = implode(',',$arr2);
+	$subquery = 'SELECT pc.product_id FROM '.cms_db_prefix().'module_products_product_categories pc
+                     LEFT JOIN '.cms_db_prefix().'module_products_categories cc
+                     ON pc.category_id = cc.id
+                     WHERE cc.name IN ('.$txt.')';
+	$where[] = 'c.id NOT IN ('.$subquery.')';
+      }
+
     if ( isset($hierarchy) && $hierarchy != '' )
       {
 	$str = " INNER JOIN ".cms_db_prefix()."module_products_prodtohier ph ON ph.product_id = c.id";
