@@ -179,6 +179,7 @@ $lang['help'] = '<h3>Que fait ce module ?</h3>
 </ul>';
 $lang['hierarchy'] = 'Hierarchie';
 $lang['hierarchy_position'] = 'Position dans la hi&eacute;rarchie';
+$lang['hierarchy_settings'] = 'Param&egrave;tres de hi&eacute;rarchie';
 $lang['id'] = 'Id ';
 $lang['imagetext'] = 'Image ';
 $lang['image_handling_settings'] = 'Param&egrave;tres de manipulation des images';
@@ -201,11 +202,12 @@ $lang['info_duplicateproducts'] = 'Traitement a appliquer aux produits dont le n
 $lang['info_fielddefs_tab'] = '<strong>Note: </strong> Les champs d&eacute;finis ici sont communs &agrave; tous les produits';
 $lang['info_fieldproblems'] = 'Une erreur est survenue lors du traitement d&#039;un ou plusieurs champs personnalis&eacute;s. L&#039;action s&#039;est termin&eacute;e correctement, mais vous devriez chercher la cause de l&#039;erreur.';
 $lang['info_handleimages'] = 'Lors de l&#039;importation, si un nom de fichier image est trouv&eacute; dans une colonne, faut-il le d&eacute;placer de son r&eacute;pertoire d&#039;origine, lui ajouter un filigrane, cr&eacute;er une miniature, et changer le type du champ associ&eacute; en champ &quot;image&quot; ?';
+$lang['info_hierpage'] = 'Par d&eacute;faut, utiliser cette page pour la vue de hierarchie. L&#039;ID de la page ne sera pas sp&eacute;cifi&eacute; dans l&#039;URL.';
 $lang['info_imagepath'] = 'Chemin (relatif au r&eacute;pertoire uploads) des images r&eacute;f&eacute;renc&eacute;es par le fichier import&eacute; ';
 $lang['info_import_test_passed'] = 'Apr&egrave;s un examen pr&eacute;liminaire, le fichier semble correct.<br/>Cependant, il se peut qu&#039;il contienne tout de m&ecirc;me des erreurs qui ne pourront &ecirc;tre d&eacute;tect&eacute;es que lors de l&#039;importation.';
+$lang['info_prettyhierurls'] = 'Inclure le nom de la hi&eacute;rarchie dans l&#039;URL';
 $lang['info_price_adjustment'] = 'Les valeurs valides sont +-*#.##';
-$lang['info_prodnotfound'] = 'Cette option param&egrave;tre le comportement du site lorsqu&#039;une fiche produit est affich&eacute;e directement &agrave; la saisie d&#039;une URL, et que ce produit ne peut &ecirc;tre affich&eacute; (pour toutes raisons : d&eacute;sactiv&eacute;, supprim&eacute;, etc.).
-This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
+$lang['info_prodnotfound'] = 'Cette option param&egrave;tre le comportement du site lorsqu&#039;une fiche produit est affich&eacute;e directement &agrave; la saisie d&#039;une URL, et que ce produit ne peut &ecirc;tre affich&eacute; (pour toutes raisons : d&eacute;sactiv&eacute;, supprim&eacute;, etc.).';
 $lang['info_publicfield'] = 'Les champs publics sont visibles par les utilisateurs.';
 $lang['label'] = '&Eacute;tiquette';
 $lang['label_skip'] = 'Ignorer';
@@ -234,7 +236,7 @@ $lang['param_action'] = 'Sp&eacute;cifie le comportement du module. Les valeurs
   <li>hierarchy - Afficher la hi&eacute;rarchie de produits</li>
   <li>categorylist - Afficher une liste de cat&eacute;gories de produits</lI
   <li><em>default</em> - Affiche le sommaire des produits</li>
-  <li>detail - Affiche le d&eacute;tail d&#039;un produit donn&eacute;</li>
+  <li>details - Affiche le d&eacute;tail d&#039;un produit donn&eacute;</li>
   <li>fieldlist - Affiche la liste des valeurs du champ sp&eacute;cifi&eacute;.
      <p>
 &nbsp;&nbsp;&nbsp;&nbsp;- Cette action peut &ecirc;tre utilis&eacute;e pour cr&eacute;er une navigation &agrave; partir des valeurs d&#039;un champ sp&eacute;cifique. Par exemple, vous pouvez cr&eacute;er une liste d&eacute;roulante personnalis&eacute;e appel&eacute;e &quot;Couleur&quot; et alors cr&eacute;er une navigation bas&eacute;e sur les diff&eacute;rentes couleurs.
@@ -255,6 +257,8 @@ $lang['param_inline'] = 'Utilis&eacute; seulement avec l&#039;action <em>search<
 $lang['param_pagelimit'] = 'Utilis&eacute; seulement avec l&#039;action <em>default</em>, ce param&egrave;tre sp&eacute;cifie combien d&#039;articles doivent &ecirc;tre list&eacute;s sur chaque page.';
 $lang['param_parent'] = 'Utilis&eacute; seulement avec l&#039;action <em>hierarchy</em>, ce param&egrave;tre indique quel est  l&#039;ID du premier &eacute;l&eacute;ment de la hi&eacute;rarchie &agrave; afficher';
 $lang['param_productid'] = 'Utilis&eacute; seulement avec l&#039;action d&eacute;tail, ce param&egrave;tre indique quels produits utiliser pour l&#039;affichage.';
+$lang['param_productlist'] = 'Utilis&eacute; seulement avec l&#039;action <em>default</em>, ce param&egrave;tre permet de sp&eacute;cifier une liste des produits &agrave; afficher via leurs IDs (&eacute;l&eacute;ments s&eacute;par&eacute;s par des virgules).
+Aucune pagination ou tri n&#039;est r&eacute;alis&eacute; en se basant sur ces valeurs, and if specified the other filtering parameters to the summary view are ignored.';
 $lang['param_resultpage'] = 'Utilis&eacute; seulement avec les actions <em>search</em> et <em>categorylist</em>, ce param&egrave;tre sp&eacute;cifie l&#039;ID ou l&#039;alias de page &agrave; utiliser pour afficher la liste des r&eacute;sultats.';
 $lang['param_searchfield'] = 'Utilis&eacute; seulement avec l&#039;action <em>search</em>, ce param&egrave;tre peut contenir une liste s&eacute;par&eacute;e par des virgules de noms de champs &agrave; inclure dans la recherche.';
 $lang['param_searchformtemplate'] = 'Utilis&eacute; seulement avec l&#039;action <em>search</em>, ce param&egrave;tre permet de d&eacute;finir le gabarit du formulaire de recherche.';
@@ -270,7 +274,7 @@ $lang['param_sortby'] = 'Utilis&eacute; seulement avec les actions <em>summary</
   <li>id -- ID</li>
   <li>weight -- Poids du produit</li>
   <li>price -- Prix de base du produit</li>
-  <li>status -- Statut : <em>Ebauche</em> ou <em>Publi&eacute;</em></li>
+  <li>status -- Statut : <em>draft</em> (&eacute;bauche) ou <em>published</em> (publi&eacute;)</li>
   <li>random -- Affiche une liste al&eacute;atoire &agrave; chaque affichage</li>
   <li>created -- Date de cr&eacute;ation de l&#039;&eacute;l&eacute;ment</li>
   <li>modified -- Date de modification de l&#039;&eacute;l&eacute;ment</li>
@@ -303,8 +307,8 @@ $lang['product_manager'] = 'Gestionnaire de produits';
 $lang['progress'] = 'Progression';
 $lang['prompt'] = 'Libell&eacute;';
 $lang['prompt_add_attribset'] = 'Ajouter/Modifier les param&egrave;tres des attributs';
-$lang['prompt_allowed_filetypes'] = 'Extensions de fichiers autoris&eacute;es (pour les champs de type fichier)';
-$lang['prompt_allowed_imagetypes'] = 'Extensions de fichiers image autoris&eacute;es (pour les champs de type image)';
+$lang['prompt_allowed_filetypes'] = 'Extensions de fichiers autoris&eacute;es (pour les champs de type fichier) ';
+$lang['prompt_allowed_imagetypes'] = 'Extensions de fichiers image autoris&eacute;es (pour les champs de type image) ';
 $lang['prompt_attribtemplate'] = 'Gabarit d&#039;affichage des valeurs d&#039;attributs de produits dans la liste d&eacute;roulante';
 $lang['prompt_autothumbnail'] = 'Cr&eacute;er automatiquement les miniatures des images';
 $lang['prompt_autothumbnail_size'] = 'Taille maximum (c&ocirc;t&eacute; le plus long) de la miniature.';
@@ -338,6 +342,8 @@ $lang['prompt_notfound_301'] = 'G&eacute;n&eacute;rer une redirection 301';
 $lang['prompt_notfound_errormsg'] = 'Afficher un message d&#039;erreur';
 $lang['prompt_notfound_msg'] = 'Message d&#039;erreur lorsqu&#039;un produit n&#039;est pas trouv&eacute; ';
 $lang['prompt_notfound_page'] = 'Page pour faire les redirections permanentes ';
+$lang['prompt_hierpage'] = 'Page par d&eacute;faut pour la vue de hi&eacute;rarchie ';
+$lang['prompt_prettyhierurls'] = 'Utiliser les Urls r&eacute;&eacute;crites pour les vues de hi&eacute;rarchie ';
 $lang['prompt_prod_detailpage'] = 'Page par d&eacute;faut pour voir le d&eacute;tail des produits ';
 $lang['prompt_products_matching'] = 'Produits correspondant &agrave; %s';
 $lang['prompt_summarypagelimit'] = 'Nombre de produits par d&eacute;faut et par page en mode Sommaire ';
@@ -347,7 +353,7 @@ $lang['prompt_template'] = 'Source du gabarit';
 $lang['prompt_true'] = 'Vrai';
 $lang['prompt_urlprefix'] = 'Pr&eacute;fixe &agrave; utiliser sur toutes les URL cibl&eacute;es de ce module';
 $lang['prompt_use_detailpage_for_search'] = 'Utiliser cette page pour les r&eacute;sultats de recherche<em>(remplace le param&egrave;tre &#039;page des r&eacute;sultats de la recherche&#039; dans le module search)</em>';
-$lang['prompt_usehierpathurls'] = 'Utiliser le &#039;Hierarchy Path&#039; dans les urls des d&eacute;tails de produit';
+$lang['prompt_usehierpathurls'] = 'Utiliser le chemin de hi&eacute;rarchie dans les urls des d&eacute;tails de produit';
 $lang['prompt_weightunits'] = 'Unit&eacute;s de poids';
 $lang['public'] = 'Est-ce un champ public ?';
 $lang['published'] = 'Publi&eacute;';
@@ -404,8 +410,9 @@ $lang['viewable_fields'] = 'S&eacute;lectionner les champs personnalis&eacute;s
 $lang['watermark_location'] = 'Emplacement du filigrane';
 $lang['weight'] = 'Poids';
 $lang['yes'] = 'Oui';
-$lang['utma'] = '156861353.1515266248.1292517082.1292517082.1292517082.1';
+$lang['utmz'] = '156861353.1300521323.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['qca'] = 'P0-2066415722-1300533676093';
+$lang['utma'] = '156861353.1283075913.1300521323.1301054358.1301063008.14';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1292517082.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
