@@ -39,9 +39,11 @@ $lang['categorylisttemplates'] = 'Kategoriliste maler';
 $lang['categorylisttemplate_addedit'] = 'Legg til/rediger kategori Listemal';
 $lang['centimeters'] = 'Centimeter';
 $lang['checkbox'] = 'Avkrysningsboks';
+$lang['confirm_copyattributes'] = 'Eventuelle eksisterende attributtsett for dette produktet vil bli fjernet. Er du sikker p&aring; at du vil fortsette?';
 $lang['confirm_delete_hierarchy_node'] = 'Er du sikker p&aring; at du vil slette denne noden? Alle produkter som bruker denne noden vil bli satt til ingen hierarki';
 $lang['confirm_import'] = 'Er du helt sikker p&aring; at du vil gj&oslash;re dette?\n\nFeil innstillinger eller en ugyldig konfigurasjonsfil kan fullstendig &oslash;delegge et n&aring; gyldig og fungerende system.';
 $lang['copy'] = 'Kopier';
+$lang['copy_attrib_sets'] = 'Kopier attributtsettene';
 $lang['copy_category'] = 'Kopier kategori';
 $lang['createddate'] = 'Opprettet dato';
 $lang['current_value'] = 'N&aring;v&aelig;rende verdi';
@@ -54,11 +56,13 @@ $lang['delete_attribset'] = 'Slett attributt';
 $lang['delete_hierarchy_item'] = 'Slett hierarki artikkel';
 $lang['descending'] = 'Synkende';
 $lang['description'] = 'Beskrivelse';
+$lang['destination'] = 'M&aring;l';
 $lang['details'] = 'Detaljer';
 $lang['detailtemplates'] = 'Detaljmaler';
 $lang['detailtemplate_addedit'] = 'Legg til/rediger en detaljmal';
 $lang['dimensions'] = 'M&aring;l';
 $lang['disabled'] = 'Deaktivert';
+$lang['down'] = 'Flytt ned';
 $lang['draft'] = 'Kladd';
 $lang['dropdown'] = 'Nedtrekk';
 $lang['dropdown_options'] = 'Nedtrekksvalg <em>(kun gyldig for nedtrekksfelt)</em><br/><br/><em>(en post pr linje)</em>';
@@ -78,6 +82,7 @@ $lang['error_filenotfound'] = 'Fil ikke funnet';
 $lang['error_fileopen'] = 'Problem med &aring; &aring;pne filen %s';
 $lang['error_invalidparent'] = 'Ugyldig foreldre (en hierarki node kan ikke v&aelig;re sin egen foreldre)';
 $lang['error_invalid_name'] = 'Ekstra(custom) feltverdien som ble oppgitt er ugyldig (inneholder ikke-alfanummeriske tegn)';
+$lang['error_invalid_value'] = 'Ugyldig verdi oppgitt';
 $lang['error_missingparam'] = 'En n&oslash;dvendig parameter mangler eller er ugyldig';
 $lang['error_nameused'] = 'En artikkel med det navnet eksisterer allerede';
 $lang['error_nofieldtype'] = 'Vennligst velg en felttype';
@@ -186,6 +191,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
 $lang['hierarchy'] = 'Hierarki';
 $lang['hierarchy_position'] = 'Hierarki posisjon';
+$lang['hierarchy_settings'] = 'Hierarki innstillinger';
 $lang['id'] = 'Id ';
 $lang['imagetext'] = 'Bilde';
 $lang['image_handling_settings'] = 'Bildebehandlingsinnstillinger';
@@ -194,9 +200,11 @@ $lang['inches'] = 'Tommer';
 $lang['include_children'] = 'Inkluder barn?';
 $lang['info_alnumonly'] = 'Kun alfanummeriske tegn. Ingen mellomrom, anf&oslash;rselstegn eller ikke-bokstav/tall kombinasjoner';
 $lang['info_attribtemplate'] = 'Mulige variabler er: ($attrib_text), ($attrib_adjust), ($currency_symbol)';
+$lang['info_attributes_copied'] = 'Atributter kopiert';
 $lang['info_autowatermark'] = 'Vannmerke innstillingene er hentet fra CGExtensions Modulen';
 $lang['info_batchsize'] = 'Sett et antall linjer som skal prosesseres per &quot;batch&quot;. Etter hver batch er ferdig, vil importereren omdirigere, og fortsette operasjonene. Om du opplever minne feil eller tidsavbrudd problemer p&aring; grunn av store mengder i prosessering, so b&oslash;r du kanskje kontakte din din nettstedsvert, eller redusere dette antallet';
 $lang['info_cart_module_params'] = 'Disse parametere gis til den valgte handlekurv(cart) modulen fra produkt-detalj og -sammendragsvisningene';
+$lang['info_copy_attribsets'] = 'Denne handlingen vil kopiere attributtsett (unntatt sku verdier) fra et annet produkt.';
 $lang['info_createfields'] = 'Opprett ukjente produktfelter automatisk? <em>(De vil bli opprettet som tekstfelter)</em>';
 $lang['info_createcategories'] = 'Opprett automatisk produktkategorier for &aring; samsvare med de som er i CSV filen, om de ikke allerede eksisterer';
 $lang['info_createhierarchy'] = 'Opprett produkthierarkier automatisk for &aring; samsvare med de som er i CSV filen, om de ikke allerede eksisterer';
@@ -206,8 +214,10 @@ $lang['info_duplicateproducts'] = 'Spesifiser hvordan systemet skal behandle et
 $lang['info_fielddefs_tab'] = '<strong>Merk: </strong> Alle felter definert her er tilgjengjelige for alle produkter.';
 $lang['info_fieldproblems'] = 'Problemer ble oppdaget under h&aring;ndtering av et eller flere ekstra(custom) felter. Handlingen er vellykket fullf&oslash;rt, men du b&oslash;r unders&oslash;ke og korrigere disse problemene';
 $lang['info_handleimages'] = 'Ved import, om et bilde filnavn blir funnet i en feltkolonne, skal det bli fjernet fra kilde lokasjonen, vannmerket, miniatyrbildet, og felttypen endres til &quot;image&quot;';
+$lang['info_hierpage'] = 'Bruk denne siden for hierarkivisninger. Dene sideID vil ikke bli spesifisert p&aring; webadressen.';
 $lang['info_imagepath'] = 'Stien (relativt til uploads katalogen) hvor bilder referert til i importfilen, kan bli funnet';
 $lang['info_import_test_passed'] = 'En kort test har blitt utf&oslash;rt p&aring; den spesifiserte innfilen, og alt ser ut til &aring; v&aelig;re i orden.<br/>Dette er ikke en indikasjon p&aring; at det ikke kan v&aelig;re feil i filen.';
+$lang['info_prettyhierurls'] = 'Inkluder hierarki elementnavnet p&aring; URLen';
 $lang['info_price_adjustment'] = 'Gyldige verdier er +-*#.##';
 $lang['info_prodnotfound'] = 'Dette alternativet bestemmer oppf&oslash;rselen til nettstedet hvis en har g&aring;tt rett til produkt-detaljvisning via en nettadresse, og at produktet av en eller annen grunn (deaktivert, slettet, osv.) ikke kan &aring;pnes.';
 $lang['info_publicfield'] = 'Offentlige felt er tilgjengelige &aring; se for alle';
@@ -259,10 +269,11 @@ $lang['param_inline'] = 'Kun nyttig for s&oslash;k-handlingen, der denne paramet
 $lang['param_pagelimit'] = 'Benyttet med <em>standard</em> handlingen vil denne parameter spesifisere hvor mange produkter som skal listes p&aring; hver side.';
 $lang['param_parent'] = 'Kan kun benyttes i <em>hierarchy</em> handlingen. Denne parameter spesifiserer hierarki id til start posisjonen i rapporten.';
 $lang['param_productid'] = 'Benyttet med detalj handlingen vil denne parameter indikere hvilket produkt som skal vises p&aring; siden.';
+$lang['param_productlist'] = 'Gjelder kun til standard (sammendrag) visning, hvor denne parameteren kan angi en kommaseparert liste med heltall produkt-IDer &aring; vise. Ingen paginering eller sortering utf&oslash;res da p&aring; disse verdiene. Andre spesifiserte filtreringsparametere, om dette er spesifisert for sammendragsvisningen, vil ogs&aring; ignoreres.';
 $lang['param_resultpage'] = 'Kun gyldig for s&oslash;k handlingen, hvor denne parameteren spesifiserer en side-id eller alias &aring; benytte for &aring; vise s&oslash;keresultatene';
 $lang['param_searchfield'] = 'Kun gyldig for s&oslash;k handlingen, hvor denne parameteren kan inneholde en kommaseparert liste med feltnavn &aring; inkludere i s&oslash;ket';
 $lang['param_searchformtemplate'] = 'Kun gyldig for s&oslash;k handlingen, hvor denne parameteren tillater &aring; spesifisere en ikke-standard s&oslash;keskjemamal';
-$lang['param_showall'] = 'Gjelder kun til categorylist handlingen, dersom denne parameteren er satt til en ikke 0 heltallsverdi vil alle kategorier (ogs&aring; de uten produkter) bli vist.';
+$lang['param_showall'] = 'Gjelder kun til categorylist og fieldlist handlingene, dersom denne parameteren er satt til en ikke 0 heltallsverdi vil alle kategorier (ogs&aring; de uten produkter) bli vist.';
 $lang['param_sortorder'] = 'Specify the order of sorted fields in summary view.  Possible values are:
 <ul>
   <li><strong>asc</strong> -- Ascending order</li>
@@ -300,6 +311,8 @@ $lang['product'] = 'Produkt';
 $lang['productname'] = 'Produktnavn';
 $lang['products'] = 'Produkt administrasjon';
 $lang['product_detail_settings'] = 'Produkt detaljinnstillinger';
+$lang['product_editing_settings'] = 'Produktredigerings innstillinger';
+$lang['product_summary_settings'] = 'Produktsammendrag innstillinger';
 $lang['product_hierarchy'] = 'Produkt hierarki';
 $lang['product_manager'] = 'Produkt behandler';
 $lang['progress'] = 'Fremdrift';
@@ -340,6 +353,8 @@ $lang['prompt_notfound_301'] = 'Generer en 301 omdirigering';
 $lang['prompt_notfound_errormsg'] = 'Vis en feilmelding';
 $lang['prompt_notfound_msg'] = 'Feilmelding for n&aring;r et produkt ikke blir funnet';
 $lang['prompt_notfound_page'] = 'Side &aring; omdirigere til permanent?';
+$lang['prompt_hierpage'] = 'Standardside for hierarkivisning';
+$lang['prompt_prettyhierurls'] = 'Benytt vakre URLer for hierarkivisningene';
 $lang['prompt_prod_detailpage'] = 'Standardside for Product detaljvisning';
 $lang['prompt_products_matching'] = 'Produkter som passer %s';
 $lang['prompt_summarypagelimit'] = 'Standard sidegrense i sammendragsmodus';
@@ -368,6 +383,7 @@ $lang['select_one'] = 'Velg en';
 $lang['sku'] = 'V.nr.(SKU)';
 $lang['sort_by'] = 'Sorter etter';
 $lang['sort_order'] = 'Sorteringsrekkef&oslash;lge';
+$lang['source'] = 'Kilde';
 $lang['status'] = 'Status ';
 $lang['submit'] = 'Utf&oslash;r';
 $lang['subscription'] = 'Abonnement';
@@ -393,6 +409,7 @@ $lang['title_detail_dflttemplate'] = 'Standard ny detaljmal';
 $lang['title_search_dflttemplate'] = 'Standard ny s&oslash;kemal';
 $lang['title_summary_dflttemplate'] = 'Standard ny sammendragsmal';
 $lang['type'] = 'Type ';
+$lang['up'] = 'Flytt opp';
 $lang['update'] = 'Oppdater';
 $lang['upload'] = 'Velg en fil &aring; laste opp';
 $lang['url_alias'] = 'URL alias';
@@ -404,9 +421,9 @@ $lang['viewable_fields'] = 'Velg brukerdefinerte felter som skal vises i tabelle
 $lang['watermark_location'] = 'Vannmerke lokasjon';
 $lang['weight'] = 'Vekt';
 $lang['yes'] = 'Ja';
-$lang['utmz'] = '156861353.1288991067.3364.78.utmccn=(referral)|utmcsr=cmsmadesimple.org|utmcct=/about-link/special-fans-listing/|utmcmd=referral';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1290034209.1290107730.3395';
+$lang['utmz'] = '156861353.1292071197.3458.79.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,49989.0/topicseen.html';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1295909416.1295985955.3518';
 $lang['qca'] = '1210971690-27308073-81952832';
-$lang['utmb'] = '156861353.1.10.1290107730';
+$lang['utmb'] = '156861353.2.10.1295985955';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
