@@ -270,6 +270,7 @@ $lang['param_inline'] = 'Useful only with the search action, this parameter spec
 $lang['param_pagelimit'] = 'Useful only with the <em>default</em> action, this parameter specifies how many items should be listed on each page.';
 $lang['param_parent'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies the hierarchy id of the starting location of the report.';
 $lang['param_productid'] = 'Heeft alleen zin in de uitgebreide sjabloon. Deze parameter geeft aan welk product te gebruiken bij het weergeven.';
+$lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored.';
 $lang['param_resultpage'] = 'Applicable only to the search action, this parameter specifies a page id or alias to use to display the search results';
 $lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
 $lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
@@ -416,8 +417,8 @@ $lang['viewable_fields'] = 'Selecteer velden om in het tabel te tonen';
 $lang['watermark_location'] = 'Plaats Watermerk';
 $lang['weight'] = 'Gewicht';
 $lang['yes'] = 'Ja';
-$lang['utma'] = '156861353.1852221271.1287479092.1295778890.1295801371.96';
-$lang['utmz'] = '156861353.1295801371.96.62.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
+$lang['utma'] = '156861353.1852221271.1287479092.1297233296.1297405951.112';
+$lang['utmz'] = '156861353.1297192927.110.70.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
 $lang['qca'] = 'P0-161031897-1287479092171';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
